@@ -1,3 +1,5 @@
+import logging
+
 from apispec import APISpec
 from apispec.ext.marshmallow import MarshmallowPlugin
 from flask import Flask, session
@@ -30,7 +32,7 @@ class Application:
 
     # ------------------------------------------------------------------------
     def install_specs__rest(self, endpoint):
-        print(f"Install Specs REST endpoints on {endpoint}")
+        logging.info(f"Openfabric - install Specs REST endpoints on {endpoint}")
         specs = {
             'APISPEC_SPEC': APISpec(
                 title="App " + manifest.get('name'),
@@ -52,7 +54,7 @@ class Application:
 
     # ------------------------------------------------------------------------
     def install_execution_rest(self, endpoint):
-        print(f"Install Execution REST endpoints on {endpoint}")
+        logging.info(f"Openfabric - install Execution REST endpoints on {endpoint}")
 
         resource_args = dict(state=self.state)
 
@@ -62,9 +64,9 @@ class Application:
     # ------------------------------------------------------------------------
     def install_config_rest(self, endpoint):
         if ConfigSchema is None:
-            print(f"No Config schema available")
+            logging.warning(f"Openfabric - no Config schema available")
             return
-        print(f"Install Config REST endpoints on {endpoint}")
+        logging.info(f"Openfabric - install Config REST endpoints on {endpoint}")
 
         resource_args = dict(state=self.state)
 
@@ -73,19 +75,19 @@ class Application:
 
     # ------------------------------------------------------------------------
     def install_manifest_rest(self, endpoint):
-        print(f"Install Manifest REST endpoints on {endpoint}")
+        logging.info(f"Openfabric - install Manifest REST endpoints on {endpoint}")
         self.__api.add_resource(ManifestRestApi, endpoint)
         self.__docs.register(ManifestRestApi)
 
     # ------------------------------------------------------------------------
     def install_benchmark_rest(self, endpoint):
-        print(f"Install Benchmark REST endpoints on {endpoint}")
+        logging.info(f"Openfabric - install Benchmark REST endpoints on {endpoint}")
         self.__api.add_resource(BenchmarkRestApi, endpoint)
         self.__docs.register(BenchmarkRestApi)
 
     # ------------------------------------------------------------------------
     def install_execution_queue(self, endpoint):
-        print(f"Install Execution REST Queue endpoints on {endpoint}")
+        logging.info(f"Openfabric - install Execution REST Queue endpoints on {endpoint}")
 
         resource_args = dict(state=self.state)
 
@@ -103,12 +105,12 @@ class Application:
 
     # ------------------------------------------------------------------------
     def install_execution_socket(self, endpoint):
-        print(f"Install Execution SOCKET endpoints on {endpoint}")
+        logging.info(f"Openfabric - install Execution SOCKET endpoints on {endpoint}")
         self.__socket = Socket(endpoint, session, self.__app, self.state)
 
     # ------------------------------------------------------------------------
     def install_configuration(self):
-        print(f"Install APP configuration")
+        logging.info(f"Openfabric - install APP configuration")
         if config_callback_function:
             items = state_config.all().items()
             config = dict(map(lambda kv: (kv[0], ConfigSchema().load(kv[1])), items))
