@@ -1,3 +1,4 @@
+import logging
 import os
 import threading
 import traceback
@@ -71,7 +72,7 @@ class ForegroundEngine:
                 ray.status = RayStatus.COMPLETED
                 ray.progress(step=100)
             except Exception as e:
-                print(f"Failed executing: [{qid}]{e}")
+                logging.error(f"Openfabric - failed executing: [{qid}]{e}")
                 traceback.print_exc()
                 ray.status = RayStatus.FAILED
         ray.finished = True
@@ -151,7 +152,7 @@ class BackgroundEngine:
             try:
                 self.__current_qid = self.__task.next()
             except:
-                print("Queue empty!")
+                logging.warning("Openfabric - queue empty!")
                 traceback.print_exc()
             finally:
                 self.__lock.release()
