@@ -24,6 +24,6 @@ class ExecutionRestApi(MethodResource, Resource):
     @marshal_with(OutputSchema)  # marshalling
     def post(self, *args) -> OutputClass:
         sid = uuid.uuid4().hex
-        data = list(args) if InputSchema().many is True else args[0]
+        data = InputSchema().dump(list(args) if InputSchema().many is True else args[0])
         qid = foreground.prepare(data, sid=sid, state=self.__state)
         return foreground.process(qid)
